<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Program_Name</source>
        <translation>Program_Name</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="29"/>
        <source>Usage</source>
        <translation>Használata</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="229"/>
        <source>Dock Preview</source>
        <translation>Dokk előnézet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="241"/>
        <source>Add New Application</source>
        <translation>Új alkalmazás hozzáadása</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="641"/>
        <source>Command</source>
        <translation>Parancs</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="118"/>
        <source>Add application</source>
        <translation>Alkalmazás hozzáadása</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="212"/>
        <source>Delete this application</source>
        <translation>Alkalmazás törlése</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="400"/>
        <source>Border</source>
        <translation>Keret</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="247"/>
        <source>Size</source>
        <translation>Méret</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="664"/>
        <source>Background</source>
        <translation>Háttér</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="198"/>
        <source>Back</source>
        <translation>Vissza</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="465"/>
        <source>File</source>
        <translation>Fájl</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="504"/>
        <location filename="../mainwindow.cpp" line="861"/>
        <location filename="../mainwindow.cpp" line="979"/>
        <location filename="../mainwindow.cpp" line="1017"/>
        <location filename="../mainwindow.cpp" line="1042"/>
        <source>Select icon...</source>
        <translation>Ikon kiválasztása...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="677"/>
        <location filename="../mainwindow.cpp" line="102"/>
        <location filename="../mainwindow.cpp" line="800"/>
        <location filename="../mainwindow.cpp" line="865"/>
        <location filename="../mainwindow.cpp" line="982"/>
        <source>Select...</source>
        <translation>Választás...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="132"/>
        <source>Move right</source>
        <translation>Mozgatás jobbra</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="146"/>
        <source>Move left</source>
        <translation>Mozgatás balra</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="273"/>
        <location filename="../mainwindow.ui" line="338"/>
        <location filename="../mainwindow.ui" line="514"/>
        <location filename="../mainwindow.ui" line="579"/>
        <source>Click to select different color...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="407"/>
        <source>Apply style to all</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="414"/>
        <source>Hover Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="442"/>
        <source>36x36</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="447"/>
        <source>40x40</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="491"/>
        <source>Hover Border</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="716"/>
        <source>Display help </source>
        <translation>Súgó megjelenítése</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="719"/>
        <source>Help</source>
        <translation>Súgó</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="726"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="755"/>
        <source>About this application</source>
        <translation>Az alkalmazásról</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="758"/>
        <source>About...</source>
        <translation>Névjegy...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="765"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="797"/>
        <source>Quit application</source>
        <translation>Kilépés az alkalmazásból</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="800"/>
        <source>Close</source>
        <translation>Bezárás</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="807"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="848"/>
        <source>Save</source>
        <translation>Mentés</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="855"/>
        <source>Alt+S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="128"/>
        <source>1. Add applications to the dock one at a time
2. Select a .desktop file or enter a command for the application you want
3. Select icon attributes for size, background (black is standard) and border
4. Press &quot;Add application&quot; to continue or &quot;Save&quot; to finish</source>
        <translation>1. Alkalmazások egyenként történő hozzáadása a dokkhoz.
2. Válasszon ki egy .desktop fájlt, vagy adja meg a kívánt alkalmazás parancsát.
3. Válassza ki az ikon tulajdonságait a méretre, a háttérre (a fekete a szabványos) és a keretre vonatkozóan.
4. A folytatáshoz nyomja meg az &quot;Alkalmazás hozzáadása&quot; gombot, vagy a befejezéshez a &quot;Mentés&quot; gombot.</translation>
    </message>
    <message>
        <source>black</source>
        <translation type="vanished">fekete</translation>
    </message>
    <message>
        <source>white</source>
        <translation type="vanished">fehér</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="166"/>
        <source>This tool allows you to create a new dock with one or more applications. You can also edit or delete a dock created earlier.</source>
        <translation>Ezzel az eszközzel új dokkot hozhat létre egy vagy több alkalmazással. Egy korábban létrehozott dokkot is szerkeszthet vagy törölhet.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="169"/>
        <source>Operation mode</source>
        <translation>Működési mód</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="175"/>
        <source>&amp;Close</source>
        <translation>&amp;Bezárás</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="171"/>
        <source>&amp;Move</source>
        <translation>&amp;Mozgatás</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="172"/>
        <source>&amp;Delete</source>
        <translation>&amp;Törlés</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="173"/>
        <source>&amp;Edit</source>
        <translation>&amp;Szerkesztés</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="174"/>
        <source>C&amp;reate</source>
        <translation>&amp;Létrehozás</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="288"/>
        <source>Dock name</source>
        <translation>Dokk neve</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="288"/>
        <source>Enter the name to show in the Menu:</source>
        <translation>Adja meg a menüben megjelenítendő nevet:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="389"/>
        <source>Select dock to delete</source>
        <translation>Válassza ki a törölni kívánt dokkot</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="394"/>
        <source>Confirmation</source>
        <translation>Jóváhagyás</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="394"/>
        <source>Are you sure you want to delete %1?</source>
        <translation>Biztos, hogy törölni szeretné ezt: %1?</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="vanished">&amp;Mégsem</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="172"/>
        <source>Next</source>
        <translation>Következő</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="425"/>
        <source>Select dock to move</source>
        <translation>Válassza ki a mozgatni kívánt dokkot</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="390"/>
        <location filename="../mainwindow.cpp" line="426"/>
        <location filename="../mainwindow.cpp" line="641"/>
        <location filename="../mainwindow.cpp" line="926"/>
        <source>Dock Files (*.mxdk);;All Files (*.*)</source>
        <translation>Dokk fájlok (*.mxdk);;Minden fájl (*.*)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="403"/>
        <source>Error</source>
        <translation type="unfinished">Hiba</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="403"/>
        <source>Failed to delete the selected dock.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="436"/>
        <location filename="../mainwindow.cpp" line="461"/>
        <location filename="../mainwindow.cpp" line="937"/>
        <source>Could not open file</source>
        <translation>Fájl megnyitása nem sikerült</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="639"/>
        <source>Overwrite?</source>
        <translation>Felülírja?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="639"/>
        <source>Do you want to overwrite the dock file?</source>
        <translation>Felül szeretné írni a dokkfájlt?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="640"/>
        <source>Save file</source>
        <translation>Fájl mentése</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="713"/>
        <source>Dock saved</source>
        <translation>Dokk mentve</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="714"/>
        <source>The dock has been saved.

To edit the newly created dock please select &apos;Edit an existing dock&apos;.</source>
        <translation>A dokk mentésre került.

Az újonnan létrehozott dokk szerkesztéséhez válassza a &apos;Meglévő dokk szerkesztése&apos; lehetőséget.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="732"/>
        <source>About %1</source>
        <translation>%1 névjegye</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="732"/>
        <source>MX Dockmaker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="733"/>
        <source>Version: </source>
        <translation>Verzió:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="734"/>
        <source>Description goes here</source>
        <translation>Leírás helye</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="737"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="738"/>
        <source>%1 License</source>
        <translation>%1 licenc</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="747"/>
        <source>%1 Help</source>
        <translation>%1 Súgó</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="904"/>
        <source>Select .desktop file</source>
        <translation>Válassza ki a .desktop fájlt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="905"/>
        <source>Desktop Files (*.desktop)</source>
        <translation>Desktop fájlok (*.desktop)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="925"/>
        <source>Select a dock file</source>
        <translation>Válasszon ki egy dokk fájlt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="930"/>
        <source>No file selected</source>
        <translation>Nincs kijelölt fájl</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="931"/>
        <source>You haven&apos;t selected any dock file to edit.
Creating a new dock instead.</source>
        <translation>Nem választott ki dokkfájlt szerkesztésre.
Új dokk kerül létrehozásra.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="938"/>
        <source>Could not open selected file.
Creating a new dock instead.</source>
        <translation>Nem sikerült a kiválasztott fájl megnyitása.
Inkább egy új dokk kerül létrehozásra.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="946"/>
        <source>1. Edit applications one at a time using the Back and Next buttons
2. Add or delete applications as you like
3. When finished click Save</source>
        <translation>1. Az alkalmazások egyenkénti szerkesztése a Vissza és a Tovább gombok segítségével.
2. Hozzáadhat vagy törölhet alkalmazásokat tetszés szerint.
3. Ha végzett, kattintson a Mentés gombra.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1023"/>
        <source>Select icon</source>
        <translation>Válasszon ikont</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1024"/>
        <source>Icons (*.png *.jpg *.bmp *.xpm *.svg)</source>
        <translation>Ikonok (*.png *.jpg *.bmp *.xpm *.svg)</translation>
    </message>
</context>
<context>
    <name>PickLocation</name>
    <message>
        <location filename="../picklocation.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialógus</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="23"/>
        <source>Dock Location</source>
        <translation>Dokk helye</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="29"/>
        <source>TopCenter</source>
        <translation>Fent középen</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="45"/>
        <source>BottomLeft</source>
        <translation>Lent balra</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="61"/>
        <source>BottomCenter</source>
        <translation>Lent középen</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="80"/>
        <source>TopLeft</source>
        <translation>Fent balra</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="96"/>
        <source>TopRight</source>
        <translation>Fent jobbra</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="112"/>
        <source>LeftCenter</source>
        <translation>Balra középen</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="128"/>
        <source>RightCenter</source>
        <translation>Jobbra középen</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="144"/>
        <source>BottomRight</source>
        <translation>Lent jobbra</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="160"/>
        <source>RightTop</source>
        <translation>Jobbra fent</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="173"/>
        <source>LeftTop</source>
        <translation>Balra fent</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="189"/>
        <source>LeftBottom</source>
        <translation>Balra lent</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="205"/>
        <source>RightBottom</source>
        <translation>Jobbra lent</translation>
    </message>
    <message>
        <location filename="../picklocation.cpp" line="9"/>
        <source>Select dock location</source>
        <translation>Válassza ki a dokk helyét</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>License</source>
        <translation type="vanished">Licenc</translation>
    </message>
    <message>
        <source>Changelog</source>
        <translation type="vanished">Változások listája</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">Mégsem</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="vanished">&amp;Bezárás</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="vanished">Hiba</translation>
    </message>
    <message>
        <source>You must run this program as normal user.</source>
        <translation type="vanished">Egyszerű felhasználóként kell futtatnia ezt a programot.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="41"/>
        <source>License</source>
        <translation type="unfinished">Licenc</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <location filename="../about.cpp" line="51"/>
        <source>Changelog</source>
        <translation type="unfinished">Változások listája</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="43"/>
        <source>Cancel</source>
        <translation type="unfinished">Mégsem</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="64"/>
        <source>&amp;Close</source>
        <translation type="unfinished">&amp;Bezárás</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="59"/>
        <location filename="../main.cpp" line="75"/>
        <source>Error</source>
        <translation type="unfinished">Hiba</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="60"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="75"/>
        <source>You must run this program as normal user.</source>
        <translation type="unfinished">Egyszerű felhasználóként kell futtatnia ezt a programot.</translation>
    </message>
</context>
</TS>
